docker: Update QEMU/Robot docker to bionic
Artful has gone end of release and will no longer build in docker due to
this. Update to the LTS.
easy_install was deprecated in bionic so use pip3 for all package
installations now.
The latest robot uses python3 so adjust our call to use that.
ipmitool in bionic is at 1.8.18 and I verified it works against our
latest master code on witherspoon so just apt-get that package.
Testing:
Ran through run-qemu-robot-test.sh and verified it passed. Did get some
warnings the test team will need to look into but everything still
passed:
Error in file '/tmp/root/11554/obmc-robot/tests/ipmi/test_fru.robot': Escaping empty cells with '\' before line continuation marker '...' is deprecated. Remove escaping before Robot Framework 3.2.
Change-Id: I16268b4042c31ca71cf6db9f37c85f66f65d4606
Signed-off-by: Andrew Geissler <geissonator@yahoo.com>
diff --git a/scripts/run-robot.sh b/scripts/run-robot.sh
index 25d2808..f4fc34e 100755
--- a/scripts/run-robot.sh
+++ b/scripts/run-robot.sh
@@ -20,7 +20,7 @@
MACHINE=${MACHINE:-"qemu"}
ROBOT_CODE_HOME=${ROBOT_CODE_HOME:-/tmp/$(whoami)/${RANDOM}/obmc-robot/}
-ROBOT_TEST_CMD=${ROBOT_TEST_CMD:-"python -m robot\
+ROBOT_TEST_CMD=${ROBOT_TEST_CMD:-"python3 -m robot\
-v OPENBMC_HOST:${IP_ADDR}\
-v SSH_PORT:${SSH_PORT}\
-v HTTPS_PORT:${HTTPS_PORT}\
diff --git a/scripts/build-qemu-robot-docker.sh b/scripts/build-qemu-robot-docker.sh
index 72e40a8..8ee4ef3 100755
--- a/scripts/build-qemu-robot-docker.sh
+++ b/scripts/build-qemu-robot-docker.sh
@@ -6,12 +6,12 @@
# parm1: <optional, the name of the docker image to generate>
# default is openbmc/ubuntu-robot-qemu
# param2: <optional, the distro to build a docker image against>
# default is ubuntu:artful
set -uo pipefail
DOCKER_IMG_NAME=${1:-"openbmc/ubuntu-robot-qemu"}
-DISTRO=${2:-"ubuntu:artful"}
+DISTRO=${2:-"ubuntu:bionic"}
# Determine our architecture, ppc64le or the other one
if [ $(uname -m) == "ppc64le" ]; then
@@ -64,34 +64,24 @@
openssl \
libxml2-dev \
libxslt-dev \
- python3-pip
+ python3-pip \
+ ipmitool
-RUN easy_install \
+RUN pip3 install \
tox \
- pip \
- requests
-
-RUN pip install \
+ requests \
json2yaml \
robotframework \
robotframework-requests \
robotframework-sshlibrary \
robotframework-scplibrary \
pysnmp \
- redfish
-
-RUN pip3 install \
+ redfish \
beautifulsoup4 --upgrade \
lxml \
jsonschema \
redfishtool
-RUN wget https://sourceforge.net/projects/ipmitool/files/ipmitool/1.8.18/ipmitool-1.8.18.tar.bz2
-RUN tar xvfj ipmitool-*.tar.bz2
-RUN ./ipmitool-1.8.18/configure
-RUN make
-RUN make install
-
RUN grep -q ${GROUPS} /etc/group || groupadd -g ${GROUPS} ${USER}
RUN grep -q ${UID} /etc/passwd || useradd -d ${HOME} -m -u ${UID} -g ${GROUPS} \
${USER}
@@ -6,12 +6,12 @@
# default is openbmc/ubuntu-robot-qemu
# param2: <optional, the distro to build a docker image against>
-# default is ubuntu:artful
+# default is ubuntu:bionic
set -uo pipefail
DOCKER_IMG_NAME=${1:-"openbmc/ubuntu-robot-qemu"}